==> agnostos-0.9.7.tar.gz: agnostos/agnostos_docroot/set_view.pl <==
#!/usr/bin/perl -w

# Copyright (C) 2000 Julian T. J. Midgley <jtjm@xenoclast.org>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# A copy of version 2 of the GNU General Public License may be found
# in the file "LICENCE" in the original Agnostos installation driectory.

use taskman_lib;
use strict;
use CGI;

#--------------------------------------------------------------------------
# disp_select($name)
sub
disp_select 
{
    my $name = shift @_;
    my ($entid, $entname) = get_table($name);
    my ($tmpid, $tmpname);
    my $comb;
    my $dbh = dbserver_connect('agnostos');
    my $dbq = $dbh -> prepare ("SELECT $entid, $entname FROM $name");
    $dbq -> execute;
    print "<tr><td>$name:<td><select name=$name>\n";
    while (($tmpid, $tmpname) = $dbq -> fetchrow_array) {
	$comb = $name."_".$tmpid;
	print "<option value=$comb>$tmpname\n";
    }
    print "</select>\n";
    $dbq -> finish;
    $dbh -> disconnect;
}
	   


#--------------------------------------------------------------------------
# main



my @foobar = ('user','workgroup','department');
my $foo;
my $query = new CGI;

print html_header("Task Manager - View Selection", $query);
print "<h2>View Selection</h2>\n";
print "Selecting combinations of User, Group and Department allows you to refine your selection.\n";
print "<form action=view_tasks.pl method=post><table>\n";
foreach $foo (@foobar) {
    disp_select ($foo);
}
print "<tr><td>Show Done/Cancelled items<td><input type=checkbox name=cancelled value=true>\n";
print "<tr><td><input type=submit value=\"View Entries\"><td>&nbsp;</table></form>\n";
print "    <h1>Edit Users, Groups and Departments</h1>
    <ul>
      <li><a href=\"name_manage.pl?table=user\">Edit Users</a></li>
      <li><a href=\"name_manage.pl?table=workgroup\">Edit Workgroups</a></li>
      <li><a href=\"name_manage.pl?table=department\">Edit Departments</a></li>
    </ul>";

print html_footer;

==> agnostos-0.9.10.tar.gz: agnostos/agnostos_docroot/set_view.pl <==
#!/usr/bin/perl -w

# Copyright (C) 2000 Julian T. J. Midgley <jtjm@xenoclast.org>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
# A copy of version 2 of the GNU General Public License may be found
# in the file "LICENCE" in the original Agnostos installation driectory.

use taskman_lib;
use strict;
use CGI;
use CGI::Carp qw(fatalsToBrowser);

#--------------------------------------------------------------------------
# disp_select($name, $tableref)
sub
disp_select 
{
    my ($name, $tableref) = @_;
    my ($entid, $entname) = get_table($name);
    my ($tmpid, $tmpname);
    my $comb;
    my %config = get_config;
    my $dbh = dbserver_connect(\%config);
    my $dbq = $dbh -> prepare ("SELECT $entid, $entname FROM $name");
    my $ent_table;
    
    $dbq -> execute;
    print "<tr><td>$name:<td><select name=$name>\n";

    while (($tmpid, $tmpname) = $dbq -> fetchrow_array) {
	$comb = $name."_".$tmpid;
	print "<option value=$comb";
	print " selected" if((defined $$tableref{$name}) && ($$tableref{$name} eq $tmpid));
	print ">$tmpname\n";
    }
    print "</select>\n";
    $dbq -> finish;
    $dbh -> disconnect;
}
	   


#--------------------------------------------------------------------------
# main



my @foobar = ('user','workgroup','department');
my $foo;
my $query = new CGI;
my $tableref;

print html_header("Task Manager - View Selection", $query);
print "<h2>View Selection</h2>\n";
print "Selecting combinations of User, Group and Department allows you to refine your selection.\n";
print "<form action=view_tasks.pl method=post><table>\n";

$tableref=get_cookie($query);

foreach $foo (@foobar) {
    disp_select ($foo, $tableref);
}
print "<tr><td>Show Done/Cancelled items<td><input type=checkbox name=cancelled value=true>\n";
print "<tr><td><input type=submit value=\"View Entries\"><td>&nbsp;</table></form>\n";
print "    <h1>Edit Users, Groups and Departments</h1>
    <ul>
      <li><a href=\"name_manage.pl?table=user\">Edit Users</a></li>
      <li><a href=\"name_manage.pl?table=workgroup\">Edit Workgroups</a></li>
      <li><a href=\"name_manage.pl?table=department\">Edit Departments</a></li>
    </ul>";

print html_footer;
